##  Share Results
To share initial results with stakeholders and show the value of SAP LeanIX, you can use the following features:
  * Reports: Use reports to share insights from your initial application portfolio assessment. You can start with the application landscape report with lifecycle information. To learn more about using reports, see [Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD).
  * Presentations: Add reports and diagrams to presentations to share insights directly in SAP LeanIX, without using third-party tools. For more information, see [Presentations](https://help.sap.com/docs/leanix/ea/presentations?locale=en-US&state=PRODUCTION&version=CLOUD "Use presentations to share enterprise architecture insights from reports and diagrams with your organization, without the need to export data to external presentation tools.").
  * Dashboards: Create a custom dashboard and add relevant content, such as reports, diagrams. saved searches, and KPIs. To learn how to create a custom dashboard, see [Dashboards](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD "Dashboards enable you to consolidate and interpret data in one place, facilitating informed decision-making and promoting efficient task management. Learn how to create, customize, and manage dashboards.").
  * Diagrams: Visualize your architecture landscape using diagrams. For more information, see [Diagrams](https://help.sap.com/docs/leanix/ea/diagrams?locale=en-US&state=PRODUCTION&version=CLOUD).


Depending on the interest group you want to present your results to, consider these tips for various types of insights:
  * High-level: Focus on key insights without delving into details. Use concise formats such as presentations or dashboards with summary charts to provide a clear overview.
  * Mid-level: Use reports, diagrams, dashboards, and presentations tailored to specific needs. If insights are distributed across multiple items, such as reports, use presentations or dashboards. You can navigate to specific entities from them as needed, such as specific fact sheets.
  * Specific: Formulate precise questions to address stakeholders' needs and use dedicated reports. For example, you can use the application landscape report to show business-critical applications.
